@@ -33,7 +33,6 @@ from oslotest import base as test_base
 import six
 
 from oslo_concurrency import processutils
-from oslotest import mockpatch
 
 
 PROCESS_EXECUTION_ERROR_LOGGING_TEST = """#!/bin/bash
@@ -113,12 +112,17 @@ class UtilsTest(test_base.BaseTestCase):
 
         processutils.execute(TRUE_UTILITY)
 
-        expected_exception = (processutils.InvalidArgumentError if six.PY2
-                              else subprocess.SubprocessError)
-        self.assertRaises(expected_exception,
-                          processutils.execute,
-                          TRUE_UTILITY,
-                          preexec_fn=preexec_fn)
+        if six.PY2:
+            self.assertRaises(processutils.InvalidArgumentError,
+                              processutils.execute,
+                              TRUE_UTILITY,
+                              preexec_fn=preexec_fn)
+        else:
+            try:
+                processutils.execute(TRUE_UTILITY, preexec_fn=preexec_fn)
+            except Exception as e:
+                if type(e).__name__ != 'SubprocessError':
+                    raise
 
 
 class ProcessExecutionErrorTest(test_base.BaseTestCase):
@@ -284,7 +288,7 @@ grep foo
     # This test and the one below ensures that when communicate raises
     # an OSError, we do the right thing(s)
     def test_exception_on_communicate_error(self):
-        mock = self.useFixture(mockpatch.Patch(
+        mock = self.useFixture(fixtures.MockPatch(
             'subprocess.Popen.communicate',
             side_effect=OSError(errno.EAGAIN, 'fake-test')))
 
@@ -297,7 +301,7 @@ grep foo
         self.assertEqual(1, mock.mock.call_count)
 
     def test_retry_on_communicate_error(self):
-        mock = self.useFixture(mockpatch.Patch(
+        mock = self.useFixture(fixtures.MockPatch(
             'subprocess.Popen.communicate',
             side_effect=OSError(errno.EAGAIN, 'fake-test')))
 
@@ -312,7 +316,7 @@ grep foo
 
     def _test_and_check_logging_communicate_errors(self, log_errors=None,
                                                    attempts=None):
-        mock = self.useFixture(mockpatch.Patch(
+        mock = self.useFixture(fixtures.MockPatch(
             'subprocess.Popen.communicate',
             side_effect=OSError(errno.EAGAIN, 'fake-test')))
 
